<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'fondness_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','fondness-pro' ),
	'description'       => esc_html__( 'Counter Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            fondness_pro_is_second_layout( $control )
            ||
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_counter_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[counter_section_enable]',
    ) );
}

// counter image setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fondness_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Counter BG Image', 'fondness-pro' ),
		'section'     		=> 'fondness_pro_counter_section',
		'active_callback'	=> 'fondness_pro_is_counter_section_enable',
) ) );

// about sub title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['counter_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[counter_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_counter_section',
	'active_callback' 	=> 'fondness_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[counter_subtitle]', array(
		'selector'            => '#counter-section h3.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[counter_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_counter_subtitle_partial',
    ) );
}

// about sub title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['counter_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[counter_title]', array(
	'label'           	=> esc_html__( 'Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_counter_section',
	'active_callback' 	=> 'fondness_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[counter_title]', array(
		'selector'            => '#counter-section h2.section-title',
		'settings'            => 'fondness_pro_theme_options[counter_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_counter_title_partial',
    ) );
}

// counter number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_counter_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_counter_section',
	'active_callback'   => 'fondness_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Counter content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'fondness-pro' ),
	'section'           => 'fondness_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_counter_section_enable',
	'choices'			=> array(
		'col-3'      => esc_html__( 'Three Column', 'fondness-pro' ),
		'col-4'      => esc_html__( 'Four Column', 'fondness-pro' ),
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :
	
	// counter title setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[counter_value_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fondness_pro_theme_options[counter_value_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'fondness-pro' ), $i ),
		'section'        	=> 'fondness_pro_counter_section',
		'active_callback' 	=> 'fondness_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[counter_label_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fondness_pro_theme_options[counter_label_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'fondness-pro' ), $i ),
		'section'        	=> 'fondness_pro_counter_section',
		'active_callback' 	=> 'fondness_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Fondness_Pro_Customize_Horizontal_Line( $wp_customize, 'fondness_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'fondness_pro_counter_section',
			'active_callback' => 'fondness_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;