<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'fondness_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','fondness-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'	=>  function( $control ) {
        return ( 
        	fondness_pro_is_default_layout( $control )
            ||
            fondness_pro_is_second_layout( $control )
            ||
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_cta_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design' ){

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#cta .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[cta_section_enable]',
    ) );
}

}else{

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[cta_section_enable]', array(
		'selector'            => '#business-cta-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[cta_section_enable]',
    ) );
}

}

// counter image setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_bg_image]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fondness_pro_theme_options[cta_bg_image]',
		array(
		'label'       		=> esc_html__( 'CTA BG Image', 'fondness-pro' ),
		'section'     		=> 'fondness_pro_cta_section',
		'active_callback'	=> 'fondness_pro_is_cta_section_enable',
) ) );

// cta sub_title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_sub_title]',
	array(
		'default'       		=> $options['cta_sub_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'fondness_pro_theme_options[cta_sub_title]',
    array(
		'label'      			=> esc_html__( 'Sub Title', 'fondness-pro' ),
		'section'    			=> 'fondness_pro_cta_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'fondness_pro_is_cta_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[cta_sub_title]', array(
		'selector'            => '#cta p.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[cta_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_cta_sub_title_partial',
    ) );
}

if( $options['home_layout'] == 'default-design' ){

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['cta_excerpt_length'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_excerpt_length]', array(
	'label'       		=> esc_html__( 'CTA Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in latest posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_cta_section',
	'active_callback' 	=> 'fondness_pro_is_cta_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

}

// CTA content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'fondness-pro' ),
		'post' 		=> esc_html__( 'Post', 'fondness-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'fondness-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'fondness-pro' ),
	'section'           => 'fondness_pro_cta_section',
	'choices'			=> fondness_pro_page_choices(),
	'active_callback'	=> 'fondness_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'fondness-pro' ),
	'section'           => 'fondness_pro_cta_section',
	'choices'			=> fondness_pro_post_choices(),
	'active_callback'	=> 'fondness_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_cta_section',
	'active_callback' 	=> 'fondness_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

if( $options['home_layout'] == 'default-design' ){

// cta description setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['cta_description'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_cta_section',
	'active_callback' 	=> 'fondness_pro_is_cta_section_content_custom_enable',
	'type'				=> 'textarea',
) );

}

// cta btn title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_cta_section',
	'active_callback' 	=> 'fondness_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[cta_btn_title]', array(
		'selector'            => '#cta div.read-more a',
		'settings'            => 'fondness_pro_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_cta_btn_title_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_cta_section',
	'active_callback' 	=> 'fondness_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );