<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'fondness_pro_popular_posts_section', array(
	'title'             => esc_html__( 'Popular Posts','fondness-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            fondness_pro_is_fifth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },	
) );

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_section_enable]', array(
	'default'			=> 	$options['popular_posts_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[popular_posts_section_enable]', array(
	'label'             => esc_html__( 'Popular Posts Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_popular_posts_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[popular_posts_section_enable]', array(
		'selector'            => '#blog-popular-posts .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[popular_posts_section_enable]',
    ) );
}

// Popular Posts btn label setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_posts_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[popular_posts_title]', array(
	'label'           	=> esc_html__( 'Section Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_popular_posts_section',
	'active_callback' 	=> 'fondness_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[popular_posts_title]', array(
		'selector'            => '#blog-popular-posts h2.section-title',
		'settings'            => 'fondness_pro_theme_options[popular_posts_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_popular_posts_title_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_count]', array(
	'default'          	=> $options['popular_posts_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_popular_posts_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[popular_posts_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_popular_posts_section',
	'active_callback'   => 'fondness_pro_is_popular_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['popular_posts_excerpt_length'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[popular_posts_excerpt_length]', array(
	'label'       		=> esc_html__( 'Popular Post Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in latest posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_popular_posts_section',
	'active_callback' 	=> 'fondness_pro_is_popular_posts_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Popular Posts btn label setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_btn_text]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_posts_btn_text'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[popular_posts_btn_text]', array(
	'label'           	=> esc_html__( 'Button Label', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_popular_posts_section',
	'active_callback' 	=> 'fondness_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// Popular Posts content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_content_type]', array(
	'default'          	=> $options['popular_posts_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[popular_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_popular_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_popular_posts_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'fondness-pro' ),
		'post'      => esc_html__( 'Post', 'fondness-pro' ),
		'category'  => esc_html__( 'Category', 'fondness-pro' ),
		),
) );

for ( $i = 1; $i <= $options['popular_posts_count']; $i++ ) :
	// latest_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_popular_posts_section',
		'choices'			=> fondness_pro_page_choices(),
		'active_callback'	=> 'fondness_pro_is_popular_posts_section_content_page_enable',
	) ) );

	// latest_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_popular_posts_section',
		'choices'			=> fondness_pro_post_choices(),
		'active_callback'	=> 'fondness_pro_is_popular_posts_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[popular_posts_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[popular_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_popular_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_popular_posts_section_content_category_enable'
) ) );