<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'fondness_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','fondness-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'	=> function( $control ) {
        return ( 
            fondness_pro_is_second_layout( $control )
            ||
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_default_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_testimonial_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[testimonial_section_enable]', array(
		'selector'            => '#testimonial-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[testimonial_section_enable]',
    ) );
}

// Testimonial auto play enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_auto_play]', array(
	'default'			=> 	$options['testimonial_auto_play'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[testimonial_auto_play]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_testimonial_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
	'active_callback' 	=> 'fondness_pro_is_testimonial_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 20. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_testimonial_section',
	'active_callback'   => 'fondness_pro_is_testimonial_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 20,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['testimonial_excerpt_length'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[testimonial_excerpt_length]', array(
	'label'       		=> esc_html__( 'Testimonial Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in testimonial posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_testimonial_section',
	'active_callback' 	=> 'fondness_pro_is_testimonial_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_testimonial_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'fondness-pro' ),
		'post' 		=> esc_html__( 'Post', 'fondness-pro' ),
		'category' 	=> esc_html__( 'Category', 'fondness-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_testimonial_section',
		'choices'			=> fondness_pro_page_choices(),
		'active_callback'	=> 'fondness_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_testimonial_section',
		'choices'			=> fondness_pro_post_choices(),
		'active_callback'	=> 'fondness_pro_is_testimonial_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_author_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'fondness_pro_theme_options[testimonial_author_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Author Position %d', 'fondness-pro' ), $i ),
		'section'        	=> 'fondness_pro_testimonial_section',
		'active_callback' 	=> 'fondness_pro_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Fondness_Pro_Customize_Horizontal_Line( $wp_customize, 'fondness_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'fondness_pro_testimonial_section',
			'active_callback' => 'fondness_pro_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;