<?php
/**
 * Work Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add Work section
$wp_customize->add_section( 'fondness_pro_work_section', array(
	'title'             => esc_html__( 'Our Work','fondness-pro' ),
	'description'       => esc_html__( 'Work Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            fondness_pro_is_default_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// Work content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[work_section_enable]', array(
	'default'			=> 	$options['work_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[work_section_enable]', array(
	'label'             => esc_html__( 'Work Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_work_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[work_section_enable]', array(
		'selector'            => '#work-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[work_section_enable]',
    ) );
}

// Subtitle setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[work_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => $options['work_sub_title'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'fondness_pro_theme_options[work_sub_title]', array(
		'label'             => sprintf( esc_html__( 'Sub Title', 'fondness-pro' ) ),
		'section'        	=> 'fondness_pro_work_section',
		'active_callback' 	=> 'fondness_pro_is_work_section_enable',
		'type'				=> 'text',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[work_sub_title]', array(
		'selector'            => '#work-section p.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[work_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_work_sub_title_partial',
    ) );
}

// Title setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[work_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => $options['work_title'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'fondness_pro_theme_options[work_title]', array(
		'label'             => sprintf( esc_html__( 'Title', 'fondness-pro' ) ),
		'section'        	=> 'fondness_pro_work_section',
		'active_callback' 	=> 'fondness_pro_is_work_section_enable',
		'type'				=> 'text',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[work_title]', array(
		'selector'            => '#work-section h2.section-title',
		'settings'            => 'fondness_pro_theme_options[work_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_work_title_partial',
    ) );
}

// Short Description setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[work_short_description]', array(
		'sanitize_callback' => 'wp_kses_post',
		'default' => $options['work_short_description'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'fondness_pro_theme_options[work_short_description]', array(
		'label'             => sprintf( esc_html__( 'Short Description', 'fondness-pro' ) ),
		'section'        	=> 'fondness_pro_work_section',
		'active_callback' 	=> 'fondness_pro_is_work_section_enable',
		'type'				=> 'textarea',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[work_short_description]', array(
		'selector'            => '#work-section div.section-content p',
		'settings'            => 'fondness_pro_theme_options[work_short_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_work_short_description_partial',
    ) );
}


// Event social icons number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[work_count]', array(
	'default'          	=> $options['work_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_work_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[work_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 100. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_work_section',
	'active_callback'   => 'fondness_pro_is_work_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 100,
		'style' => 'width: 100px;'
		),
) );

// Work content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[work_content_type]', array(
	'default'          	=> $options['work_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[work_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_work_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_work_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'fondness-pro' ),
            'post'      => esc_html__( 'Post', 'fondness-pro' ),
            'category'  => esc_html__( 'Category', 'fondness-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[work_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[work_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_work_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_work_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['work_count']; $i++ ) :

	// work pages drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[work_content_page_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[work_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_work_section',
		'choices'			=> fondness_pro_page_choices(),
		'active_callback'	=> 'fondness_pro_is_work_section_content_page_enable',
	) ) );

	// work posts drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[work_content_post_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[work_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_work_section',
		'choices'			=> fondness_pro_post_choices(),
		'active_callback'	=> 'fondness_pro_is_work_section_content_post_enable',
	) ) );

endfor;