<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function fondness_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'fondness-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function fondness_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'fondness-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function fondness_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'fondness-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function fondness_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'fondness-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function fondness_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'fondness-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'fondness_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function fondness_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'fondness-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'fondness_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function fondness_pro_selected_sidebar() {
        $fondness_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'fondness-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'fondness-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'fondness-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'fondness-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'fondness-pro' ),
        );

        $output = apply_filters( 'fondness_pro_selected_sidebar', $fondness_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'fondness_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function fondness_pro_site_layout() {
        $fondness_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'fondness_pro_site_layout', $fondness_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'fondness_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function fondness_pro_global_sidebar_position() {
        $fondness_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'fondness_pro_global_sidebar_position', $fondness_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'fondness_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function fondness_pro_sidebar_position() {
        $fondness_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'fondness_pro_sidebar_position', $fondness_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'fondness_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function fondness_pro_pagination_options() {
        $fondness_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'fondness-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'fondness-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'fondness-pro' ),
        );

        $output = apply_filters( 'fondness_pro_pagination_options', $fondness_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'fondness_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function fondness_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'fondness-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'fondness-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'fondness-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'fondness-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'fondness-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'fondness-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'fondness-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'fondness-pro' ),
        );
        return apply_filters( 'fondness_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'fondness_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function fondness_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'fondness-pro' ),
            'off'       => esc_html__( 'Disable', 'fondness-pro' )
        );
        return apply_filters( 'fondness_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'fondness_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function fondness_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'fondness-pro' ),
            'off'       => esc_html__( 'No', 'fondness-pro' )
        );
        return apply_filters( 'fondness_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'fondness_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function fondness_pro_sortable_sections() {
        $sections = array(
            'slider'            => esc_html__( 'Slider Section', 'fondness-pro' ),
            'about'             => esc_html__( 'About Us Section', 'fondness-pro' ),
            'cta'               => esc_html__( 'CTA Section', 'fondness-pro' ),
            'solution'          => esc_html__( 'Our Solution Section', 'fondness-pro' ),
            'testimonial'       => esc_html__( 'Testimonial Section', 'fondness-pro' ),
            'work'              => esc_html__( 'Work Section', 'fondness-pro' ),
            'latest_posts'      => esc_html__( 'Latest Post Section', 'fondness-pro' ),
            'subscription'      => esc_html__( 'Subscription Section', 'fondness-pro' ),
            'instagram'         => esc_html__( 'Instagram Section', 'fondness-pro' ),
            'business_about'    => esc_html__( 'Business About Us Section', 'fondness-pro' ),
            'counter'           => esc_html__( 'Counter Section', 'fondness-pro' ),
            'service'           => esc_html__( 'Services Section', 'fondness-pro' ),
            'team'              => esc_html__( 'Team Section', 'fondness-pro' ),
            'gallery'           => esc_html__( 'Gallery Section', 'fondness-pro' ),
            'featured_posts'    => esc_html__( 'Featured Posts', 'fondness-pro' ),
            'popular_posts'         => esc_html__( 'Popular Posts', 'fondness-pro' ),
        );
        return apply_filters( 'fondness_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'fondness_pro_heading_tags' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function fondness_pro_heading_tags() {
        
        $fondness_pro_heading_tags = array(
			'h1'	=> esc_html__('H1', 'fondness-pro'),
			'h2'	=> esc_html__('H2', 'fondness-pro'),
			'h3'	=> esc_html__('H3', 'fondness-pro'),
			'h4'	=> esc_html__('H4', 'fondness-pro'),
			'h5'	=> esc_html__('H5', 'fondness-pro'),
			'h6'	=> esc_html__('H6', 'fondness-pro'),
			'p'		=> esc_html__('Paragraph', 'fondness-pro'),
		);

        $output = apply_filters( 'fondness_pro_heading_tags', $fondness_pro_heading_tags );


        return $output;
    }
endif;