<?php
/**
 * Business About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_business_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_business_about_section() {
    	$options = fondness_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $business_about_enable = apply_filters( 'fondness_pro_section_status', true, 'business_about_section_enable' );

        if ( true !== $business_about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'fondness_pro_filter_business_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        fondness_pro_render_business_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'fondness_pro_get_business_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Fondness Pro 1.0.0
    * @param array $input about section details.
    */
    function fondness_pro_get_business_about_section_details( $input ) {
        $options = fondness_pro_get_theme_options();

        // Content type.
        $business_about_content_type  = $options['business_about_content_type'];
        
        $content = array();
        switch ( $business_about_content_type ) {

            case 'custom':
                $custom['title']        = ! empty( $options['business_about_title'] ) ? $options['business_about_title'] : '';
                $custom['excerpt']      = ! empty( $options['business_about_description'] ) ? $options['business_about_description'] : '';
                $custom['image']        = ! empty( $options['business_about_image'] ) ? $options['business_about_image'] : '';
                $custom['url']          = ! empty( $options['business_about_btn_link'] ) ? $options['business_about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;
        	
            case 'page':
                $page_id = ! empty( $options['business_about_content_page'] ) ? $options['business_about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['business_about_content_post'] ) ? $options['business_about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $business_about_content_type ) :

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = fondness_pro_trim_content( $options['business_about_excerpt_length'] );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'fondness_pro_filter_business_about_section_details', 'fondness_pro_get_business_about_section_details' );


if ( ! function_exists( 'fondness_pro_render_business_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_business_about_section( $content_details = array() ) {
        $options = fondness_pro_get_theme_options();
        $business_about_subtitle = ! empty( $options['business_about_subtitle'] ) ? $options['business_about_subtitle'] : '';
        $business_about_btn_title = ! empty( $options['business_about_btn_title'] ) ? $options['business_about_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <?php 

        foreach ( $content_details as $content ) :
    ?>
        <div id="fondness_pro_business_about_section">
            <div id="education-about-us" class="relative page-section">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                fondness_pro_section_tooltip( 'education-about-us' );
                endif; ?>
                    <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no' ; ?>-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ) ; ?>');">
                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="section-header">
                            <?php if( !empty( $business_about_subtitle ) ): ?>
                                <h3 class="section-subtitle"><?php echo esc_html( $business_about_subtitle ) ; ?></h3>
                            <?php endif; ?>

                             <?php if( !empty( $content['title'] ) && !empty( $content['url'] ) ): ?>
                                <h2 class="section-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                            <?php endif; ?>

                            </div><!-- .section-header -->

                            <?php if( !empty( $content['excerpt'] ) ): ?>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ) ; ?></p>
                            </div><!-- .entry-content -->
                        <?php endif; ?>

                            <?php if ( ! empty( $options['business_about_btn_title'] ) && !empty( $content['url'] ) ): ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="btn"><?php echo esc_html( $options['business_about_btn_title'] ) ; ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->

        </div>
        

    <?php 
    endforeach;
}
endif;