<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_counter_section() {
        $options = fondness_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'fondness_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        fondness_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'fondness_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_counter_section() {
        $options = fondness_pro_get_theme_options();
        $counter_column = ! empty( $options['counter_column'] ) ? $options['counter_column'] : 'col-4';
        $image = !empty( $options['counter_image'] ) ? $options['counter_image'] : '';
        $counter_title = !empty( $options['counter_title'] ) ? $options['counter_title'] : '';
        $counter_subtitle = !empty( $options['counter_subtitle'] ) ? $options['counter_subtitle'] : '';
      
        ?>
       <div id="fondness_pro_counter_section">
         <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
          <div class="overlay"></div>
          <div class="wrapper">
            <?php if ( is_customize_preview()):
            fondness_pro_section_tooltip( 'counter-section' );
            endif; ?>

            <div class="section-header">
            <?php if( !empty( $counter_subtitle ) ): ?>
              <h3 class="section-subtitle"><?php echo esc_html( $counter_subtitle ); ?></h3>
            <?php endif;
              if( !empty( $counter_title ) ):
             ?>
              <h2 class="section-title"><?php echo esc_html( $counter_title ); ?></h2>
            <?php endif; ?>
            </div><!-- .section-header -->

            <div class="<?php echo esc_attr( $counter_column ); ?> clear">

              <?php for ( $i = 1; $i <= $options['counter_count']; $i++){
                ?>

                <article>
                  <div class="counter-item">
                    <?php if( !empty( $options['counter_value_' . $i] ) && !empty( $options['counter_label_' . $i] ) ): ?>
                      <h2 class="counter-value"><?php echo esc_html( $options['counter_value_' . $i] ); ?></h2>
                      <h3 class="counter-title"><?php echo esc_html( $options['counter_label_' . $i] ); ?></h3>
                    <?php endif; ?>
                  </div><!-- .counter-item -->
                </article>

                <?php } ?>

              </div><!-- .col-4 -->
            </div><!-- .wrapper -->
          </div><!-- #counter-section -->
       </div>
        
            
    <?php }
endif;