<?php
/**
 * Popular Posts section
 *
 * This is the template for the content of popular_posts section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_popular_posts_section' ) ) :
    /**
    * Add popular_posts section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_popular_posts_section() {
        $options = fondness_pro_get_theme_options();
        // Check if popular_posts is enabled on frontpage
        $popular_posts_enable = apply_filters( 'fondness_pro_section_status', true, 'popular_posts_section_enable' );

        if ( true !== $popular_posts_enable ) {
            return false;
        }
        // Get popular_posts section details
        $section_details = array();
        $section_details = apply_filters( 'fondness_pro_filter_popular_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render popular_posts section now.
        fondness_pro_render_popular_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'fondness_pro_get_popular_posts_section_details' ) ) :
    /**
    * popular_posts section details.
    *
    * @since Fondness Pro 1.0.0
    * @param array $input popular_posts section details.
    */
    function fondness_pro_get_popular_posts_section_details( $input ) {
        $options = fondness_pro_get_theme_options();

        // Content type.
        $popular_posts_content_type  = $options['popular_posts_content_type'];
        $popular_posts_count = !empty( $options['popular_posts_count'] ) ? $options['popular_posts_count'] : 2;
        $content = array();
        switch ( $popular_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['popular_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $popular_posts_count; $i++ ) {
                    if ( ! empty( $options['popular_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['popular_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['popular_posts_content_category'] ) ? $options['popular_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $popular_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = fondness_pro_trim_content( $options['popular_posts_excerpt_length'] );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular_posts section content details.
add_filter( 'fondness_pro_filter_popular_posts_section_details', 'fondness_pro_get_popular_posts_section_details' );


if ( ! function_exists( 'fondness_pro_render_popular_posts_section' ) ) :
  /**
   * Start popular_posts section
   *
   * @return string popular_posts content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_popular_posts_section( $content_details = array() ) {
        $options = fondness_pro_get_theme_options();

        $section_title = !empty( $options['popular_posts_title'] ) ? $options['popular_posts_title'] : '';
        $btn = !empty( $options['popular_posts_btn_text'] ) ? $options['popular_posts_btn_text'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="fondness_pro_popular_posts_section">
            <div id="blog-popular-posts" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                    fondness_pro_section_tooltip( 'blog-popular-posts' );
                    endif; ?>
                <div class="section-header">
                    <?php if( !empty( $section_title ) ): ?>
                        <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
                    <?php endif; ?>
                </div>

                <div class="col-2 clear">

                    <?php foreach ( $content_details as $content ) : ?>

                        <article>
                            <div class="popular-post-item">
                                <div class="blog-featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>"></a>
                                </div><!-- .blog-featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>                            
                                    </span><!-- .cat-links -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <?php fondness_pro_posted_on( $content['id'] ); ?>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div>

                                    <?php if( !empty( $btn ) ): ?>

                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $btn ); ?></a>
                                        </div>

                                    <?php endif; ?>

                                </div><!-- .entry-container -->
                            </div><!-- .popular-post-item -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .blog-section-content -->
            </div><!-- .wrapper -->
        </div><!-- #blog-popular-posts -->
        </div>
        

    <?php }
    endif;