<?php
/**
 * team section
 *
 * This is the template for the content of team section
 *
 * @team Theme Palace
 * @subteam Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_team_section' ) ) :
    /**
    * Add team section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_team_section() {
        $options = fondness_pro_get_theme_options();
        // Check if team is enabled on frontpage
        $team_enable = apply_filters( 'fondness_pro_section_status', true, 'team_section_enable' );


        if ( true !== $team_enable ) {
            return false;
        }
        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'fondness_pro_filter_team_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render team section now.
        fondness_pro_render_team_section( $section_details );
    }
endif;

if ( ! function_exists( 'fondness_pro_get_team_section_details' ) ) :
    /**
    * team section details.
    *
    * @since Fondness Pro 1.0.0
    * @param array $input team section details.
    */
    function fondness_pro_get_team_section_details( $input ) {
        $options = fondness_pro_get_theme_options();

        // Content type.
        $team_content_type  = $options['team_content_type'];
        $team_count  = ! empty( $options['team_count'] ) ? $options['team_count'] : 3;
        
        $content = array();
        switch ( $team_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_page_' . $i] ) )
                        $page_ids[] = $options['team_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $team_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $team_count; $i++ ) {
                    if ( ! empty( $options['team_content_post_' . $i] ) )
                        $post_ids[] = $options['team_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $team_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['team_content_category'] ) ? $options['team_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $team_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = fondness_pro_trim_content( $options['team_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'fondness_pro_filter_team_section_details', 'fondness_pro_get_team_section_details' );


if ( ! function_exists( 'fondness_pro_render_team_section' ) ) :
  /**
   * Start team section
   *
   * @return string team content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_team_section( $content_details = array() ) {
        $options = fondness_pro_get_theme_options();
        $team_sub_title = ! empty( $options['team_sub_title'] ) ? $options['team_sub_title'] : '';
        $team_title = ! empty( $options['team_title'] ) ? $options['team_title'] : '';
        $team_column = ! empty( $options['team_column'] ) ? $options['team_column'] : 'col-3';
        
        if ( empty( $content_details ) ) {
            return;
        } 
        ?> 
        <div id="fondness_pro_team_section">
               <div id="our-team" class="relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                fondness_pro_section_tooltip( 'our-team' );
                endif; ?>
                <div class="section-header">
                <?php if( !empty( $team_sub_title ) ): ?>
                    <h3 class="section-subtitle"><?php echo esc_html( $team_sub_title ); ?></h3>
                <?php endif;

                        if( !empty( $team_title ) ):

                 ?>
                    <h2 class="section-title"><?php echo esc_html( $team_title ); ?></h2>

                <?php endif; ?>

                </div><!-- .section-header -->

                <div class="section-content <?php echo esc_attr( $team_column ); ?> clear">

                    <?php $i = 1; foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="team-item-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="team <?php echo esc_attr( $i+1 ); ?> "></a>
                            </div><!-- .featured-image -->

                            <header class="entry-header">
                                 <?php if ( !empty( $options['team_position_'.$i] )): ?>
                                    <span class="team-position"><?php echo esc_html( $options['team_position_'.$i] ) ; ?></span>
                                <?php endif; ?>
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ) ; ?>"><?php echo esc_html( $content['title'] ) ; ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ) ; ?></p>
                            </div><!-- .entry-content -->

                            <div class="social-icons">
                                <ul>
                                     <?php 
                                        $team_socials = ! empty( $options['team_social_' . $i ] ) ? explode( '|', $options['team_social_' . $i ] ) : array(); 

                                        foreach ( $team_socials as $team_social ) : ?>
                                        <li>
                                            <a href="<?php echo esc_url( $team_social ); ?>"><?php echo fondness_pro_return_social_icon( $team_social ); ?></a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div><!-- .social-icons -->
                        </div><!-- team-item-wrapper -->
                    </article>

                    <?php $i++; endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #our-team -->
        </div>
     

    <?php }
endif;